# Appendix III: Legal notes as flat-pages

This appendix gives examples of flat pages containing privacy and terms of
conditions. Such statements should be added as flat-pages in the [django admin
panel](AfterDeployment.html#the-web-ui-admin-panel).
[Flat-pages](https://docs.djangoproject.com/en/4.1/ref/contrib/flatpages/)
additional notes that are displayed on the web site. Any flat-page url
starting with `/legal/` will be added as a link to the footer.
For example `/legal/privacy/` which could be a flat-page for a privacy
statement. Below you'll find examples of a privacy statement and terms of use.

### Privacy statement

```html

<h1 id="privacy-policy">Privacy Policy</h1>
<p>The internet sites under the current main website page (hereinafter: "Website") are operated by Deutsches Klimarechenzentrum GmbH (hereinafter: "DKRZ"), Bundesstraße 45a, 20146 Hamburg. The careful and legitimate handling of your data is an important concern for us. The following Privacy Policy explain which personal data are gathered on our website and how and for which purposes these are used.</p>
<p>Please, read the Privacy Policy completely before you transmit data to us or use our website in other manner and inform yourself about updates of these Data protection notices on a regular basis. The following Privacy Policy is valid for the use of our website in its respective current version.</p>
<h3 id="automatic-collection-of-data">Automatic Collection of data</h3>
<p>When you visit our website, the following data are automatically gathered exclusively for the creation of anonymous statistics as well as for the purposes of data protection monitoring, data security and to ensure the proper operation of our data processing systems:</p>
<ul>
<li><p>The IP address of your computer</p></li>
<li><p>Date and time of the visit</p></li>
<li><p>Operating system and the browser software of your computer</p></li>
<li><p>Volume of data transmitted</p></li>
<li><p>Internet address of the website from which you have reached this website</p></li>
<li><p>Domain and Host, from which you are using the Internet</p></li>
</ul>
<h3 id="other-collection-processing-and-use-of-personal-data">Other collection, processing and use of personal data</h3>
<p>As a rule, you can visit our website without us requiring, collecting, processing or using your personal data. You will remain anonymous as an individual user or at least pseudonymous.</p>
<p>Personal data are only collected if you provide them to us voluntarily, in particular during registration and use of the current instance of the Free Evaluation System Framework (Freva) website.</p>
<p>Your information will not be disclosed to third parties and is used exclusively for the execution of these services and for processing your request and remain stored only up to the final processing of the matter of the case and in compliance with statutory retention periods.</p>
<h3 id="freva-registration-and-use">Freva: Registration and use</h3>
<p>To be able to use the current instance of Freva, you must register as a user via <a href="https://luv.dkrz.de/">DKRZ's LDAP system</a>. On this occasion, we also collect personal data like given name (First Name), surname, e-mail address, user name as well as, optionally: the second given name (Middle Name), Organisation, City (State -) country (State), country (Country). Besides, you must select a separate password; this is stored encoded, of course. The thus collected information is stored on a server of the DKRZ.</p>
<p>The thus collected data are stored only on our servers for the purpose and for the duration of the use of the Freva server operated by us and are not disclosed to any third party.</p>
<h3 id="withdrawal-of-consent-for-the-collection-processing-and-use-of-your-data">Withdrawal of consent for the collection, processing and use of your data</h3>
<p>You have the option to revoke your consent for the collection, processing and use of personal data at any time with effect for the future. A revocation must be sent to:</p>
<p><br />
Deutsches Klimarechenzentrum GmbH<br />
Bundesstraße 45a<br />
D-20146 Hamburg<br />
e-mail: <a href="mailto:data@dkrz.de" class="email">data@dkrz.de</a><br />
Telephone: +49404600940<br />
Telefax: +4940460094270</p>
<h3 id="right-to-access-correction-blocking-and-deletion-of-your-data">Right to access, correction, blocking and deletion of your data</h3>
<p>You are entitled to receive, free of charge, information about the personal data stored about you. On request, we will share with you in writing, in accordance with the applicable law, whether and which personal data about you are stored with us.</p>
<p>In addition, in accordance with the legal provisions, you have a right to correction, blocking and deletion of your personal data.</p>
<h3 id="changes-to-the-contents-of-this-data-protection-notice">Changes to the contents of this Data protection notice</h3>
<p>DKRZ reserves the right to change the contents of these Privacy Policy every now and then in accordance with the legal data protection regulations.</p>
```


### Terms of use


```html
<h1 id="terms-of-use">Terms of Use</h1>
<p>Deutsches Klimarechenzentrum GmbH (hereinafter: "DKRZ"), Bundesstraße 45a, 20146 Hamburg, provides an Internet platform under this website and all the sites under it, with which the users are given access to the web version of the current Free Evaluation System Framework instance (hereinafter: Freva). Freva is a standardized data and evaluation system for high performance computing that provides access to a vast model and observational database as well as to tools to analyze them.</p>
<h3 id="availability-of-the-website">Availability of the Website</h3>
<p>DKRZ makes every effort to ensure the constant availability of the website. However, it is not impossible that - for technical reasons or for maintenance work purposes - this website will be temporarily unavailable from time to time, and this without prior notice. A right of the user to a continuous accessibility of the content of the website does not exist.</p>
<h3 id="use-of-freva">Use of Freva</h3>
<p>The use of Freva via our website is only allowed under protection of the copyrights and other rights of third parties. DKRZ is not obliged to verify or to monitor User Content in terms of completeness, accuracy, timeliness, non-infringement and as to its compatibility with legal provisions or other mandatory rules.</p>
<p>The user is not permitted to upload contents that violate the rights of third party parties. With content upload, the user declares to have the necessary rights to use the content in question and not to violate any laws or other mandatory rules with the contents. In case of infringement of the law, he is obliged to indemnify DKRZ against third party claims; this includes the costs for a legal defense through DKRZ.</p>
<p>Data Portal users may create individual copying (e.g. through download and printing out) for private use of the retrievable and downloadable contents there. In addition, copies are particularly permissible for scientific use if and as far as the reproduction is necessary for that purpose and serves no commercial purposes.</p>
<p>Further rights are not granted.</p>
<h3 id="liability-principles">Liability principles</h3>
<p>The visit and the use of the website is done on own responsibility of the user. A liability of the DKRZ for slightly negligent breaches of obligations is excluded, provided that this does not concern damage arising from injury to life, body or health or claims according to the product liability law. This shall furthermore not affect the liability for the breach of obligations whose fulfilment makes the proper execution of the contract generally possible in the first place and the observance of which the users may usually rely on ("cardinal contractual obligations"). However, in the case of violation of cardinal contractual obligations, compensation claims of the user are limited to compensation for contract typical, predictable damage. The same liability restrictions are valid for breaches of obligations by the legal representatives and vicarious agents of DKRZ.</p>
<p>DKRZ assumes as part of the above restrictions in particular no liability for unauthorized access by third parties to the contents of the website or manipulation by third parties as well as for a possible transmission of computer viruses, computer worms, Trojans or other malicious programs. The user is obliged to undertake own precautions for the protection of his own computer against such malicious programs, in particular to install anti-virus software and to use the respectively current antivirus definitions.</p>
<h3 id="liability-for-third-party-content">Liability for Third Party Content</h3>
<p>DKRZ shall only be liable for contents published by users or, otherwise, by a third party ("Third Party Content") according to the principles named in Clause 3. This applies in particular for all climatology data retrievable via this website, no matter whether these are stored on our own or external servers. DKRZ is not obliged to monitor third-party content as to the completeness, accuracy, timeliness, non-infringement and for compliance with statutory provisions, other mandatory rules or for compliance with professional ethics. Accordingly, DKRZ also takes over no guarantee or responsibility for the completeness, accuracy, timeliness or legality of third party contents.</p>
<h3 id="liability-for-links">Liability for Links</h3>
<p>The website contains references ("Links") to contents of external websites. The placing of such links is done exclusively for information purposes and as an additional service for the users of the website, without DKRZ thereby wanting to express a recommendation, approval or endorsement with respect to the linked content or without wanting to adopt the linked content as its own. At the time of DKRZ placing the links, there were no illegal contents recognizable on the internet sites linked to. However, DKRZ has influence neither on the creation nor the contents of the linked websites. Rather, their respective operator is exclusively responsible for the creation and contents of the linked websites. Hence, DKRZ assumes no guarantee or responsibility for the existence, the accuracy, completeness, timeliness or legality of the design and content of linked websites.</p>
<h3 id="copyright">Copyright</h3>
<p>As far as the contents on this website were not created by DKRZ, the copyrights of third parties have been observed. Concerning the contents of the current Freva website instance, Clause 2 of these Terms of Use is valid in addition. Should you become aware of copyright infringement, we ask you to inform us. Upon becoming aware of an infringement, we will undertake all reasonable steps in order to prevent this.</p>
<h3 id="data-protectionpersonal-information">Data protection/Personal information</h3>
<p>Information about the collection and processing of your personal data during the use of the website can be found in the Privacy Policy.</p>
<h3 id="applicable-law-and-place-of-jurisdiction">Applicable law and Place of Jurisdiction</h3>
<p>The law of the Federal Republic of Germany shall apply. If you are using the services on this website as a consumer and have your residence in another country at the time, the application of mandatory law of that country remains unaffected by the choice of law made in sentence 1.</p>
<p>Place of performance and Place of Jurisdiction for all disputes from and in connection with the offer of this website is Hamburg for the use by merchants, legal entities under public law or public law special funds. For the rest, the applicable legal provisions are valid for the local and international jurisdiction.</p>

```
